- [x] Prevent autocompletion from overflowing window
- [~] Prevent freeze and clutter when evaluating big data structures
- [x] Fix resume on reload when detached
- [~] Fix scroll down in prompt when interacting on non-last items
- [ ] Add option (ui buttons) for global spacing and font-size
